package net.tamas.bcpg;

import org.bouncycastle.openpgp.PGPObjectFactory;
import org.bouncycastle.bcpg.ArmoredInputStream;

import java.io.File;
import java.io.InputStream;
import java.io.FileInputStream;
import java.io.IOException;

public class FileBasedPGPObjectFactory
{

  private File file;
  private InputStream in;
  private FileInputStream fileIn;
  private PGPObjectFactory factory;

  public FileBasedPGPObjectFactory(String fileName) throws IOException
  {
    file = new File(fileName);
    boolean armored = isArmored(file);
    fileIn = new FileInputStream(file);
    in = fileIn;
    if (armored)
      in = new ArmoredInputStream(in);
    factory = new PGPObjectFactory(in);
  }

  // unarmored files begin with a PGP packet tag, the first byte of which always has it's high-order bit set on
  private boolean isArmored(File file) throws IOException
  {
    FileInputStream in = new FileInputStream(file);
    byte[] b = new byte[1];
    in.read(b);
    in.close();
    return (b[0] & 0x80) == 0;
  }

  public Object nextObject() throws IOException
  {
    return factory.nextObject();
  }

  public void close() throws IOException
  {
    fileIn.close();
  }

}
